DevToolsDropdown<T> class

Inheritance

Constructors

DevToolsDropdown({required String label, required List<DropdownMenuItem<T>>? items, required T initalElement, required void onChanged(T? value)})

Properties

hashCode int
The hash code for this object.
no setterinherited
initalElement → T
final
items List<DropdownMenuItem<T>>?
final
label String
final
onChanged → void Function(T? value)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited