DevToolsSwitch class
- Inheritance
-
- Object
- DevToolsElement
- DevToolsSwitch
Constructors
- DevToolsSwitch({required String label, required bool value, required void onChanged(bool value)})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited